Struct i2cdev::sensors::mpl115a2_barometer::MPL115A2Coefficients
[−]
[src]
pub struct MPL115A2Coefficients {
// some fields omitted
}The sensors has several coefficients that must be used in order to calculate a correct value for pressure/temperature.
This structure provides access to those. It is usually only necessary to read these coefficients once per interaction with the acclerometer. It does not need to be read again on each sample.
Methods
impl MPL115A2Coefficients
fn new(i2cdev: &mut I2CDevice) -> I2CResult<MPL115A2Coefficients>
Convert a slice of data values of length 8 to coefficients
This should be built from a read of registers 0x04-0x0B in order. This gets the raw, unconverted value of each coefficient.